@@ -7,7 +7,7 @@ my $bin = $FindBin::Bin;
 $bin =~ s#/#\\#g;
 $| = 1;
 
-for my $perlbin (qw(perl55 perl56 perl58 perl510)) {
+for my $perlbin (qw(perl55 perl56 perl58 perl510 perl512)) {
     next unless `$perlbin -v 2>NUL` =~ /This is perl,/;
 
     # "\"
